@@ -1,8 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "elisp-depmap" "20250919.1240"
+(define-package "elisp-depmap" "20251029.1438"
   "Generate an elisp dependency map in graphviz."
-  '((emacs "26.1"))
+  '((emacs "26.1")
+    (dash  "0"))
   :url "https://github.com/mtekman/elisp-depmap.el"
-  :commit "65afa5316506666888c0fb073505eb7e7c62c893"
-  :revdesc "65afa5316506"
+  :commit "c87e9ecae624b09d113c25b7ad1317d97eb2f434"
+  :revdesc "c87e9ecae624"
   :keywords '("outlines"))
